@@ -49,6 +49,11 @@ void                nautilus_tag_manager_unstar_files       (NautilusTagManager
 
 
 gboolean            nautilus_tag_manager_file_is_starred   (NautilusTagManager *self,
-                                                             const gchar        *file_name);
+                                                            const gchar        *file_uri);
 
-G_END_DECLS
\ No newline at end of file
+gboolean            nautilus_tag_manager_can_star_contents (NautilusTagManager *self,
+                                                            GFile              *directory);
+
+void                nautilus_tag_manager_maybe_migrate_tracker2_data (NautilusTagManager *self);
+
+G_END_DECLS
